@@ -363,7 +363,7 @@ sub as_list {
     $set = $set->intersection( $span ) if $span;
 
     # Note: removing this line means we may end up in an infinite loop!
-    return undef if $set->{set}->is_too_complex;  # undef = no begin/end
+    return undef if $set->{set}->is_too_complex;  # undef = no start/end
 
     # return if $set->{set}->is_null;  # nothing = empty
     my @result;
@@ -795,6 +795,10 @@ These set functions return a boolean value.
 These methods can accept a C<DateTime>, C<DateTime::Set>,
 C<DateTime::Span>, or C<DateTime::SpanSet> object as an argument.
 
+intersects() returns 1 for true, and 0 for false. In a few cases
+the algorithm can't decide if the sets intersect at all, and 
+intersects() will return C<undef>.
+
 =item * iterator / next / previous
 
 This method can be used to iterate over the spans in a set.
